.. Dr. Bryan Patrick Wood's Pandas Extension Package documentation master file, created by
   sphinx-quickstart on Sat Jan  9 11:24:07 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Dr. Bryan Patrick Wood's Pandas Extension Package's documentation!
=============================================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
